﻿using System;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Xml;

public partial class _Default : System.Web.UI.Page
{
    //Common XML file for Operations
    private string strXMLFileName = "MrBoolXML.xml";

    /// <summary>
    /// Display the list of movies on page load 
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {

        if (!IsPostBack)
            DisplayMovies();
    }

    /// <summary>
    /// Read XML DataSet to Display Movies
    /// </summary>
    /// <returns></returns>
    private DataSet GetXMLDataSet()
    {
        DataSet objDS = new DataSet();

        objDS.ReadXml(Server.MapPath(strXMLFileName));
        return objDS;
    }

    /// <summary>
    /// Read XML and return XmlDocument Object
    /// </summary>
    /// <returns></returns>
    private XmlDocument ReadXML()
    {
        XmlDocument xmlDoc = new XmlDocument();
        xmlDoc.Load(Server.MapPath(strXMLFileName));
        return xmlDoc;
    }

    /// <summary>
    /// Save the changes in XML
    /// </summary>
    /// <param name="objDoc"></param>
    private void WriteXML(XmlDocument objDoc)
    {
        objDoc.Save(Server.MapPath(strXMLFileName));
    }

    /// <summary>
    /// Display Movie list in Grid
    /// </summary>
    private void DisplayMovies()
    {
        DataSet oDs = GetXMLDataSet();
        if (oDs != null && oDs.Tables.Count > 0 && oDs.Tables[0].Rows.Count > 0)
        {
            dgData.DataSource = oDs;
            dgData.DataBind();
        }
    }

    /// <summary>
    /// Add New Movie Node
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnAddMovie_Click(object sender, EventArgs e)
    {
        XmlDocument objXMLDoc = ReadXML();

        XmlElement objElement = objXMLDoc.CreateElement("Movie");
        XmlElement ID = objXMLDoc.CreateElement("ID");
        ID.InnerText = txtMovieID.Text;
        XmlElement Title = objXMLDoc.CreateElement("Title");
        Title.InnerText = txtMovieTitle.Text;
        XmlElement Director = objXMLDoc.CreateElement("Director");
        Director.InnerText = txtMovieDirector.Text;
        XmlElement Year = objXMLDoc.CreateElement("Year");
        Year.InnerText = txtMovieYear.Text;
        XmlElement Rating = objXMLDoc.CreateElement("Rating");
        Rating.InnerText = txtMovieRating.Text;

        objElement.AppendChild(ID);
        objElement.AppendChild(Title);
        objElement.AppendChild(Director);
        objElement.AppendChild(Year);
        objElement.AppendChild(Rating);

        objXMLDoc.DocumentElement.AppendChild(objElement);
        //Save XML
        WriteXML(objXMLDoc);

        //Display Movie List again
        DisplayMovies();

    }

    /// <summary>
    /// Remove Selected Movie Node
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnRemoveMovie_Click(object sender, EventArgs e)
    {
        bool blnFlag = false;
        XmlDocument objXMLDoc = ReadXML();

        XmlNodeList lstMovies = objXMLDoc.GetElementsByTagName("Movie");

        foreach (XmlNode objNode in lstMovies)
        {
            XmlNodeList objNodeList = objNode.ChildNodes;

            foreach (XmlNode objInnerNode in objNodeList)
            {                
                if (objInnerNode.InnerText == txtMovieTitle.Text.ToString())
                {
                    objXMLDoc.DocumentElement.RemoveChild(objNode);

                    blnFlag = true;
                    break;
                }
            }
            if (blnFlag)
                break;
        }
        //Save XML
        WriteXML(objXMLDoc);

        //Display Movie List again
        DisplayMovies();

    }

}
